--
-- Chronometer v3.0.0 by SilverAzide
--
-- This work is licensed under a Creative Commons Attribution-Noncommercial-Share Alike 3.0 License.
--
-- History:
-- 4.0.0 - 2018-03-17:  Editorial changes.
-- 3.0.0 - 2017-07-06:  Initial release.
--
---------------------------------------------------------------------------------------------------
--
function Initialize()
  --
  -- this function is called when the script measure is initialized or reloaded
  --
end

function Update()
  --
  -- this function is called when the script measure is updated
  --
  return "success"
end

function JoinDaysOfTheWeekString(iDisableSun,
                                 iDisableMon,
                                 iDisableTue,
                                 iDisableWed,
                                 iDisableThu,
                                 iDisableFri,
                                 iDisableSat,
                                 sVariableName,
                                 sOutputFile)
  --
  -- this functions joins boolean values indicating whether the day is used/not used into a string
  -- of days and stores the result into a designated variable and optionally writes to a file
  --
  -- where:  iDisableSun - iDisableSat = seven boolean (0/1) values
  --         sVariableName             = name of a variable to receive the result
  --         sOutputFile               = name of output file, if needed
  --
  local aValues = {iDisableSun, iDisableMon, iDisableTue, iDisableWed, iDisableThu, iDisableFri, iDisableSat}
  local aDays = {"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"}
  local aResult = {}
  local iIsDisabled

  for i,sDay in ipairs(aDays) do
    iIsDisabled = tonumber(aValues[i])

    -- if not disabled (disabled = 1), append the day to the result array
    if iIsDisabled == 0 then
      table.insert(aResult, sDay)
    end
  end
  
  if sVariableName ~= nil then
    SKIN:Bang("!SetVariable", sVariableName, table.concat(aResult, "|"))
  
    if sOutputFile ~= nil then
      SKIN:Bang("!WriteKeyValue", "Variables", sVariableName, table.concat(aResult, "|"), sOutputFile)
    end
  end

end

function SplitDaysOfTheWeekString(sAlarmID, sDaysOfTheWeek)
  --
  -- this function splits a string representing the days of the week into boolean values and stores
  -- each result into designated variables
  --
  -- where:  sAlarmID       = alarm ID, used as part of variable name
  --         sDaysOfTheWeek = a string representing zero or more days of the week
  --
  -- NOTE: The days of the week string must contain zero to seven days in 3-letter abbreviated US
  --       format, separated by any delimiter character. Days can be in any order.
  --
  --       Examples:  "Sun|Mon|Tue|Wed|Thu|Fri|Sat" = all 7 days represented
  --                  "Mon|Wed|Fri"                 = Monday, Wednesday, Friday only
  --
  local iPos
  local iValue
  local aDays = {"Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"}
  
  for i,sDay in ipairs(aDays) do
    iPos = string.find(sDaysOfTheWeek, sDay)
    if iPos == nil then
      iValue = 1
    else
      iValue = 0
    end

    -- save the value to the variable
    SKIN:Bang("!SetVariable", "Alarm" .. sAlarmID .. "DayDisable" .. sDay, iValue)
  end

end
